#' baymedr: Computation of Bayes Factors for Common Biomedical Designs
#'
#' \code{baymedr} provides functions for the computation of Bayes factors for
#' common biomedical research designs.
#'
#' \tabular{ll}{ Package: \tab baymedr \cr Type: \tab Package \cr Version: \tab
#' 0.2 \cr License: \tab GPL-3 \cr Date: \tab 2022-09-01 \cr}
#'
#' @docType package
#' @name baymedr-package
#' @aliases baymedr-package baymedr
#' @author \strong{Maintainer}: Maximilian Linde --
#'   \email{maximilian.linde.92@@gmail.com}
#'
#'   Authors: \itemize{ \item Maximilian Linde (aut, cre) \item Don van
#'   Ravenzwaaij (aut) \item Jorge N. Tendeiro (aut)
#'   \item Quentin F. Gronau (ctb) }
#'
#' @seealso Useful links: \itemize{ \item
#'   \url{https://github.com/maxlinde/baymedr} \item Report bugs at
#'   \url{https://github.com/maxlinde/baymedr/issues}}
"_PACKAGE"
